AuthMethodOAuth2 class

Response DTO of oauth2 auth method option.

Implemented types
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

AuthMethodOAuth2({bool enabled = false, List<AuthMethodProvider> providers = const []})

Properties

enabled bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
providers List<AuthMethodProvider>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) AuthMethodOAuth2