AuthMethodProvider class

Response DTO of a single OAuth2 provider.

Implemented types
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

AuthMethodProvider({String name = "", String displayName = "", String state = "", String codeVerifier = "", String codeChallenge = "", String codeChallengeMethod = "", String authURL = "", bool? pkce})

Properties

authURL String
getter/setter pair
authUrl String
getter/setter pair
codeChallenge String
getter/setter pair
codeChallengeMethod String
getter/setter pair
codeVerifier String
getter/setter pair
displayName String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
pkce bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) AuthMethodProvider