BackupFileInfo class

Response DTO of a backup file info entry.

Implemented types
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

BackupFileInfo({String key = "", int size = 0, String modified = ""})

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
getter/setter pair
modified String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) BackupFileInfo