BatchResult class

Response DTO of a single batch request result.

Implemented types
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

BatchResult({num status = 0, dynamic body})

Properties

body ↔ dynamic
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status num
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) BatchResult