BatchService class

The service that handles the Batch/transactional APIs.

Usually shouldn't be initialized manually and instead PocketBase.createBatch() should be used.

Constructors

BatchService(PocketBase client)

Properties

client PocketBase
no setterinherited
dummyClient PocketBase
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

collection(String collectionIdOrName) SubBatchService
Starts constructing a batch request entry for the specified collection.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send({Map<String, dynamic> body = const {}, Map<String, dynamic> query = const {}, Map<String, String> headers = const {}}) Future<List<BatchResult>>
Sends the batch requests.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited