CollectionField class

Response DTO of a single collection schema field.

Implemented types
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

CollectionField([Map<String, dynamic>? data])

Properties

data Map<String, dynamic>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hidden bool
getter/setter pair
id String
getter/setter pair
name String
getter/setter pair
presentable bool
getter/setter pair
required bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
system bool
getter/setter pair
type String
getter/setter pair

Methods

get<T>(String fieldNameOrPath, [T? defaultValue]) → T
Extracts a single model value by a dot-notation path and tries to cast it to the specified generic type.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) CollectionField