ConfigurableOAuth2Provider class

Response DTO of a single configurable OAuth2 provider item.

Implemented types
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ConfigurableOAuth2Provider({String name = "", String displayName = "", })

Properties

displayName String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) ConfigurableOAuth2Provider