Jsonable class abstract
Interface for JSON serializable classes.
- Implementers
- AppleClientSecret
- AuthAlertConfig
- AuthMethodMFA
- AuthMethodOAuth2
- AuthMethodOTP
- AuthMethodPassword
- AuthMethodProvider
- AuthMethodsList
- BackupFileInfo
- BatchResult
- CollectionField
- CollectionModel
- ConfigurableOAuth2Provider
- CronJob
- EmailTemplateConfig
- HealthCheck
- LogModel
- LogStat
- MFAConfig
- OAuth2Config
- OTPConfig
- OTPResponse
- PasswordAuthConfig
- RecordAuth
- RecordModel
- RecordSubscriptionEvent
- ResultList
- SQLResult
- TokenConfig
Constructors
- Jsonable()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited