OAuth2Config class

Response DTO of a single collection oauth2 auth config.

Implemented types
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

OAuth2Config({bool enabled = false, Map<String, String>? mappedFields, List? providers})

Properties

enabled bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mappedFields Map<String, String>
getter/setter pair
providers List
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) OAuth2Config