realtime property
An instance of the service that handles the Realtime APIs.
This service is usually used with custom realtime actions.
For records realtime subscriptions you can use the subscribe/unsubscribe
methods available in the collection() RecordService.
Implementation
late final RealtimeService realtime;