RecordModel class

Response DTO of a single record model.

Implemented types
Annotations
  • @JsonSerializable.new()

Constructors

RecordModel([Map<String, dynamic>? data])

Properties

collectionId → String
no setter
collectionName → String
no setter
created → String
no setter
data ↔ Map<String, dynamic>
getter/setter pair
expand ↔ Map<String, List<RecordModel>>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updated → String
no setter

Methods

get<T>(String fieldNameOrPath, [T? defaultValue]) → T
Extracts a single model value by a dot-notation path and tries to cast it to the specified generic type.
getBoolValue(String fieldNameOrPath, [bool? defaultValue]) → bool
An alias for get<bool>().
getDataValue<T>(String fieldNameOrPath, [T? defaultValue]) → T
getDoubleValue(String fieldNameOrPath, [double? defaultValue]) → double
An alias for get<double>().
getIntValue(String fieldNameOrPath, [int? defaultValue]) → int
An alias for get<int>().
getListValue<T>(String fieldNameOrPath, [List<T>? defaultValue]) → List<T>
An alias for get<List<T>>().
getStringValue(String fieldNameOrPath, [String? defaultValue]) → String
An alias for get<String>().
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String fieldName, dynamic value) → void
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → RecordModel