SQLResult class

Response DTO of a SQL run request result.

Implemented types
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

SQLResult({num execTime = 0, num affectedRows = 0, List columns = const [], List rows = const []})

Properties

affectedRows num
getter/setter pair
columns List
getter/setter pair
execTime num
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
rows List
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) SQLResult