SQLService class

The service that handles the SQL APIs.

Usually shouldn't be initialized manually and instead PocketBase.sql should be used.

Constructors

SQLService(PocketBase client)

Properties

client PocketBase
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(String sqlQuery, {Map<String, dynamic> body = const {}, Map<String, dynamic> query = const {}, Map<String, String> headers = const {}}) Future<SQLResult>
Executes the specified raw SQL query. This operation is allowed only for superusers.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited